pro sxt_flarepos_addmoments, catstruct, retval, $
   _extra=_extra, locut=locut, status=status

;+
;   Name: sxt_flarepos_addmoments
;
;-
if not required_tags(catstruct,'fdtime') then begin 
   box_message,'Required a flare position catalog record'
   return
endif

nrecs=n_elements(catstruct)


; add tags for moment
retval=catstruct
retval=add_tag(retval,0.,'reg_lev')
retval=add_tag(retval,0.,'reg_dist')     ; pathag distance flare:region
retval=add_tag(retval,0.,'mom_cnsn_n1')  ; No mask
retval=add_tag(retval,0.,'mom_cysn_n1')  ; core mask 
retval=add_tag(retval,0.,'mom_cysy_n1')  ; core mask & above limb mask 
retval=add_tag(retval,0.,'mom_cnsy_n1')  ; above limb mask
retval=add_tag(retval,0.,'mom_cnsn_n2')  ; (ditto for order=-2)
retval=add_tag(retval,0.,'mom_cysn_n2')
retval=add_tag(retval,0.,'mom_cysy_n2')
retval=add_tag(retval,0.,'mom_cnsy_n2')

if keyword_set(locut) then retval.reg_lev=locut

for i=0,nrecs-1 do begin
;  lookup full disk context image
   fdtime=gt_tagval(catstruct(i),/fdtime,missing='')
   delvarx,fdindex,fddata   
   get_ssc_best,fdtime,fdindex,fddata,/half,filtb=3,/earlier
   if n_elements(fdindex) eq 0 then $
      get_ssc_best,fdtime,fdindex,fddata,/half,filtb=2,/earlier

   retval(i).fdtime=anytim(fdindex,/ecs)
   retval(i).fd_dthrs=ssw_deltat(fdindex,catstruct,/hour)
   retval(i).fd_wave=gt_filtb(fdindex,/string)
   retval(i).fd_cdelt=gt_pix_size(fdindex)
   fdmask=solar_mask(fdindex,fdata)
   retval(i).fdtotal=total(fddata)
   retval(i).fddisk=total(fddata * fdmask)

   ssw_findstuff,fdindex, fddata, region, rinfo, lowcut=locut, _extra=_extra, status=status
   if status then begin 
;  match region to flare position
   dummy=make_array(retval(i).naxis1,retval(i).naxis2)
   index2map,retval(i),dummy,fmap                       ; flare map
   fx=comp_fits_crpix(fdindex.xcen,fmap.dx,fdindex.naxis1,fmap.xc) ; x pix
   fy=comp_fits_crpix(fdindex.ycen,fmap.dy,fdindex.naxis2,fmap.yc) ; y pix

   drot_xy, [fx], [fy], anytim(retval(i),/utc_int), anytim(fdindex,/utc_int), $
            rfx, rfy

   sdist=sqrt( (rinfo.centroid(0) - (rfx)(0))^2. + $
               (rinfo.centroid(1) - (rfy)(0))^2. )
   mdist=where(sdist eq min(sdist))  
   retval(i).reg_dist=sdist(mdist(0))

   regmask=region ne rinfo(mdist(0)).rnum
   
   mtags='mom_'+str2arr('cnsn,cysn,cysy,cnsy')+'_n'
   for mom=-1,-2,-1 do begin 
;  moment w/respect to all pixels
      mord=abs(mom)
      itags=mtags+strtrim(mord,2)
      tindex=tag_index(retval,itags)
      ; no mask
      retval(i).(tindex(0))=moment2d(fddata,rfx,rfy,mom)
      retval(i).(tindex(1))=moment2d(fddata,rfx,rfy,mom,mask=regmask)
      retval(i).(tindex(2))=moment2d(fddata,rfx,rfy,mom,mask=regmask*fdmask)
      retval(i).(tindex(3))=moment2d(fddata,rfx,rfy,mom,mask=fdmask)
   endfor
   endif else begin
      box_message,'No regions identified'
      retval(i).reg_dist=-1
   endelse
endfor
;     
return

end
;   
